==> ph-ubl21-6.4.0-sources.jar: oasis/names/specification/ubl/schema/xsd/unqualifieddatatypes_21/AmountType.java <==

package oasis.names.specification.ubl.schema.xsd.unqualifieddatatypes_21;

import java.io.Serializable;
import java.math.BigDecimal;
import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;
import com.helger.commons.annotation.CodingStyleguideUnaware;
import com.helger.commons.annotation.ReturnsMutableCopy;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.AdvertisementAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.AllowanceTotalAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.AnnualAverageAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.AverageAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.AverageSubsequentContractAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.BalanceAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.BaseAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.CallBaseAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.CallExtensionAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.ChargeTotalAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.CorporateStockAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.CorrectionAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.CorrectionUnitAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.CreditLineAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.DebitLineAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.DeclaredCarriageValueAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.DeclaredCustomsValueAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.DeclaredForCarriageValueAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.DeclaredStatisticsValueAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.DocumentationFeeAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.EstimatedAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.EstimatedOverallContractAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.FaceValueAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.FeeAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.FreeOnBoardValueAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.HigherTenderAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.InsurancePremiumAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.InsuranceValueAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.InventoryValueAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.LiabilityAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.LineExtensionAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.LowerTenderAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.MarketValueAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.MaximumAdvertisementAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.MaximumAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.MaximumPaidAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.MinimumAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.PaidAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.PartyCapacityAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.PayableAlternativeAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.PayableAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.PayableRoundingAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.PenaltyAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.PerUnitAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.PrepaidAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.PriceAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.RequiredFeeAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.RoundingAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.SettlementDiscountAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TaxAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TaxEnergyAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TaxEnergyBalanceAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TaxEnergyOnAccountAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TaxExclusiveAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TaxInclusiveAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TaxableAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.ThresholdAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TotalAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TotalBalanceAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TotalCreditAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TotalDebitAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TotalInvoiceAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TotalPaymentAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TotalTaskAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TotalTaxAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TransactionCurrencyTaxAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.ValueAmountType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;ccts:UniqueID xmlns:ccts="urn:un:unece:uncefact:documentation:2" xmlns:ccts-cct="urn:un:unece:uncefact:data:specification:CoreComponentTypeSchemaModule:2" xmlns:xsd="http://www.w3.org/2001/XMLSchema"&gt;UBLUDT000001&lt;/ccts:UniqueID&gt;
 * </pre>
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;ccts:CategoryCode xmlns:ccts="urn:un:unece:uncefact:documentation:2" xmlns:ccts-cct="urn:un:unece:uncefact:data:specification:CoreComponentTypeSchemaModule:2" xmlns:xsd="http://www.w3.org/2001/XMLSchema"&gt;UDT&lt;/ccts:CategoryCode&gt;
 * </pre>
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;ccts:DictionaryEntryName xmlns:ccts="urn:un:unece:uncefact:documentation:2" xmlns:ccts-cct="urn:un:unece:uncefact:data:specification:CoreComponentTypeSchemaModule:2" xmlns:xsd="http://www.w3.org/2001/XMLSchema"&gt;Amount. Type&lt;/ccts:DictionaryEntryName&gt;
 * </pre>
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;ccts:VersionID xmlns:ccts="urn:un:unece:uncefact:documentation:2" xmlns:ccts-cct="urn:un:unece:uncefact:data:specification:CoreComponentTypeSchemaModule:2" xmlns:xsd="http://www.w3.org/2001/XMLSchema"&gt;1.0&lt;/ccts:VersionID&gt;
 * </pre>
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;ccts:Definition xmlns:ccts="urn:un:unece:uncefact:documentation:2" xmlns:ccts-cct="urn:un:unece:uncefact:data:specification:CoreComponentTypeSchemaModule:2" xmlns:xsd="http://www.w3.org/2001/XMLSchema"&gt;A number of monetary units specified using a given unit of currency.&lt;/ccts:Definition&gt;
 * </pre>
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;ccts:RepresentationTermName xmlns:ccts="urn:un:unece:uncefact:documentation:2" xmlns:ccts-cct="urn:un:unece:uncefact:data:specification:CoreComponentTypeSchemaModule:2" xmlns:xsd="http://www.w3.org/2001/XMLSchema"&gt;Amount&lt;/ccts:RepresentationTermName&gt;
 * </pre>
 * 
 * 
 * <p>Java class for AmountType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="AmountType"&gt;
 *   &lt;simpleContent&gt;
 *     &lt;restriction base="&lt;urn:un:unece:uncefact:data:specification:CoreComponentTypeSchemaModule:2&gt;AmountType"&gt;
 *       &lt;attribute name="currencyID" use="required" type="{http://www.w3.org/2001/XMLSchema}normalizedString" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/simpleContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * <p>This class contains methods created by ph-jaxb22-plugin -Xph-equalshashcode</p>
 * <p>This class contains methods created by ph-jaxb22-plugin -Xph-cloneable2</p>
 * <p>This class contains methods created by ph-jaxb22-plugin -Xph-value-extender</p>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AmountType")
@XmlSeeAlso({
    AdvertisementAmountType.class,
    AllowanceTotalAmountType.class,
    oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.AmountType.class,
    AnnualAverageAmountType.class,
    AverageAmountType.class,
    AverageSubsequentContractAmountType.class,
    BalanceAmountType.class,
    BaseAmountType.class,
    CallBaseAmountType.class,
    CallExtensionAmountType.class,
    ChargeTotalAmountType.class,
    CorporateStockAmountType.class,
    CorrectionAmountType.class,
    CorrectionUnitAmountType.class,
    CreditLineAmountType.class,
    DebitLineAmountType.class,
    DeclaredCarriageValueAmountType.class,
    DeclaredCustomsValueAmountType.class,
    DeclaredForCarriageValueAmountType.class,
    DeclaredStatisticsValueAmountType.class,
    DocumentationFeeAmountType.class,
    EstimatedAmountType.class,
    EstimatedOverallContractAmountType.class,
    FaceValueAmountType.class,
    FeeAmountType.class,
    FreeOnBoardValueAmountType.class,
    HigherTenderAmountType.class,
    InsurancePremiumAmountType.class,
    InsuranceValueAmountType.class,
    InventoryValueAmountType.class,
    LiabilityAmountType.class,
    LineExtensionAmountType.class,
    LowerTenderAmountType.class,
    MarketValueAmountType.class,
    MaximumAdvertisementAmountType.class,
    MaximumAmountType.class,
    MaximumPaidAmountType.class,
    MinimumAmountType.class,
    PaidAmountType.class,
    PartyCapacityAmountType.class,
    PayableAlternativeAmountType.class,
    PayableAmountType.class,
    PayableRoundingAmountType.class,
    PenaltyAmountType.class,
    PerUnitAmountType.class,
    PrepaidAmountType.class,
    PriceAmountType.class,
    RequiredFeeAmountType.class,
    RoundingAmountType.class,
    SettlementDiscountAmountType.class,
    TaxAmountType.class,
    TaxEnergyAmountType.class,
    TaxEnergyBalanceAmountType.class,
    TaxEnergyOnAccountAmountType.class,
    TaxExclusiveAmountType.class,
    TaxInclusiveAmountType.class,
    TaxableAmountType.class,
    ThresholdAmountType.class,
    TotalAmountType.class,
    TotalBalanceAmountType.class,
    TotalCreditAmountType.class,
    TotalDebitAmountType.class,
    TotalInvoiceAmountType.class,
    TotalPaymentAmountType.class,
    TotalTaskAmountType.class,
    TotalTaxAmountType.class,
    TransactionCurrencyTaxAmountType.class,
    ValueAmountType.class
})
@CodingStyleguideUnaware
public class AmountType
    extends com.helger.xsds.ccts.cct.schemamodule.AmountType
    implements Serializable
{


    /**
     * Default constructor<br>
     * Note: automatically created by ph-jaxb22-plugin -Xph-value-extender
     * 
     */
    public AmountType() {
    }

    /**
     * Constructor for value of type BigDecimal<br>
     * Note: automatically created by ph-jaxb22-plugin -Xph-value-extender
     * 
     * @param valueParam
     *     The value to be set. May be <code>null</code>.
     */
    public AmountType(
        @Nullable
        final BigDecimal valueParam) {
        setValue(valueParam);
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-equalshashcode
     * 
     */
    @Override
    public boolean equals(final Object o) {
        return super.equals(o);
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-equalshashcode
     * 
     */
    @Override
    public int hashCode() {
        return super.hashCode();
    }

    /**
     * This method clones all values from <code>this</code> to the passed object. All data in the parameter object is overwritten!Created by ph-jaxb22-plugin -Xph-cloneable2
     * 
     * @param ret
     *     The target object to clone to. May not be <code>null</code>.
     */
    public void cloneTo(
        @Nonnull
        AmountType ret) {
        super.cloneTo(ret);
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-cloneable2
     * 
     * @return
     *     The cloned object. Never <code>null</code>.
     */
    @Nonnull
    @ReturnsMutableCopy
    @Override
    public AmountType clone() {
        AmountType ret = new AmountType();
        cloneTo(ret);
        return ret;
    }

}

==> ph-ubl21-6.7.0-sources.jar: oasis/names/specification/ubl/schema/xsd/unqualifieddatatypes_21/AmountType.java <==

package oasis.names.specification.ubl.schema.xsd.unqualifieddatatypes_21;

import java.io.Serializable;
import java.math.BigDecimal;
import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;
import com.helger.commons.annotation.CodingStyleguideUnaware;
import com.helger.commons.annotation.ReturnsMutableCopy;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.AdvertisementAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.AllowanceTotalAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.AnnualAverageAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.AverageAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.AverageSubsequentContractAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.BalanceAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.BaseAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.CallBaseAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.CallExtensionAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.ChargeTotalAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.CorporateStockAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.CorrectionAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.CorrectionUnitAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.CreditLineAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.DebitLineAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.DeclaredCarriageValueAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.DeclaredCustomsValueAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.DeclaredForCarriageValueAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.DeclaredStatisticsValueAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.DocumentationFeeAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.EstimatedAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.EstimatedOverallContractAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.FaceValueAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.FeeAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.FreeOnBoardValueAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.HigherTenderAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.InsurancePremiumAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.InsuranceValueAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.InventoryValueAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.LiabilityAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.LineExtensionAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.LowerTenderAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.MarketValueAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.MaximumAdvertisementAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.MaximumAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.MaximumPaidAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.MinimumAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.PaidAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.PartyCapacityAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.PayableAlternativeAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.PayableAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.PayableRoundingAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.PenaltyAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.PerUnitAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.PrepaidAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.PriceAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.RequiredFeeAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.RoundingAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.SettlementDiscountAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TaxAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TaxEnergyAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TaxEnergyBalanceAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TaxEnergyOnAccountAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TaxExclusiveAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TaxInclusiveAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TaxableAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.ThresholdAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TotalAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TotalBalanceAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TotalCreditAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TotalDebitAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TotalInvoiceAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TotalPaymentAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TotalTaskAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TotalTaxAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.TransactionCurrencyTaxAmountType;
import oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.ValueAmountType;


/**
 * 
 * &lt;pre&gt;
 * &amp;lt;?xml version="1.0" encoding="UTF-8"?&amp;gt;&amp;lt;ccts:UniqueID xmlns:ccts="urn:un:unece:uncefact:documentation:2" xmlns:ccts-cct="urn:un:unece:uncefact:data:specification:CoreComponentTypeSchemaModule:2" xmlns:xsd="http://www.w3.org/2001/XMLSchema"&amp;gt;UBLUDT000001&amp;lt;/ccts:UniqueID&amp;gt;
 * &lt;/pre&gt;
 * 
 * &lt;pre&gt;
 * &amp;lt;?xml version="1.0" encoding="UTF-8"?&amp;gt;&amp;lt;ccts:CategoryCode xmlns:ccts="urn:un:unece:uncefact:documentation:2" xmlns:ccts-cct="urn:un:unece:uncefact:data:specification:CoreComponentTypeSchemaModule:2" xmlns:xsd="http://www.w3.org/2001/XMLSchema"&amp;gt;UDT&amp;lt;/ccts:CategoryCode&amp;gt;
 * &lt;/pre&gt;
 * 
 * &lt;pre&gt;
 * &amp;lt;?xml version="1.0" encoding="UTF-8"?&amp;gt;&amp;lt;ccts:DictionaryEntryName xmlns:ccts="urn:un:unece:uncefact:documentation:2" xmlns:ccts-cct="urn:un:unece:uncefact:data:specification:CoreComponentTypeSchemaModule:2" xmlns:xsd="http://www.w3.org/2001/XMLSchema"&amp;gt;Amount. Type&amp;lt;/ccts:DictionaryEntryName&amp;gt;
 * &lt;/pre&gt;
 * 
 * &lt;pre&gt;
 * &amp;lt;?xml version="1.0" encoding="UTF-8"?&amp;gt;&amp;lt;ccts:VersionID xmlns:ccts="urn:un:unece:uncefact:documentation:2" xmlns:ccts-cct="urn:un:unece:uncefact:data:specification:CoreComponentTypeSchemaModule:2" xmlns:xsd="http://www.w3.org/2001/XMLSchema"&amp;gt;1.0&amp;lt;/ccts:VersionID&amp;gt;
 * &lt;/pre&gt;
 * 
 * &lt;pre&gt;
 * &amp;lt;?xml version="1.0" encoding="UTF-8"?&amp;gt;&amp;lt;ccts:Definition xmlns:ccts="urn:un:unece:uncefact:documentation:2" xmlns:ccts-cct="urn:un:unece:uncefact:data:specification:CoreComponentTypeSchemaModule:2" xmlns:xsd="http://www.w3.org/2001/XMLSchema"&amp;gt;A number of monetary units specified using a given unit of currency.&amp;lt;/ccts:Definition&amp;gt;
 * &lt;/pre&gt;
 * 
 * &lt;pre&gt;
 * &amp;lt;?xml version="1.0" encoding="UTF-8"?&amp;gt;&amp;lt;ccts:RepresentationTermName xmlns:ccts="urn:un:unece:uncefact:documentation:2" xmlns:ccts-cct="urn:un:unece:uncefact:data:specification:CoreComponentTypeSchemaModule:2" xmlns:xsd="http://www.w3.org/2001/XMLSchema"&amp;gt;Amount&amp;lt;/ccts:RepresentationTermName&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 * &lt;p&gt;Java class for AmountType complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType name="AmountType"&amp;gt;
 *   &amp;lt;simpleContent&amp;gt;
 *     &amp;lt;restriction base="&amp;lt;urn:un:unece:uncefact:data:specification:CoreComponentTypeSchemaModule:2&amp;gt;AmountType"&amp;gt;
 *       &amp;lt;attribute name="currencyID" use="required" type="{http://www.w3.org/2001/XMLSchema}normalizedString" /&amp;gt;
 *     &amp;lt;/restriction&amp;gt;
 *   &amp;lt;/simpleContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * &lt;p&gt;This class contains methods created by ph-jaxb22-plugin -Xph-equalshashcode&lt;/p&gt;
 * &lt;p&gt;This class contains methods created by ph-jaxb22-plugin -Xph-cloneable2&lt;/p&gt;
 * &lt;p&gt;This class contains methods created by ph-jaxb22-plugin -Xph-value-extender&lt;/p&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AmountType")
@XmlSeeAlso({
    AdvertisementAmountType.class,
    AllowanceTotalAmountType.class,
    oasis.names.specification.ubl.schema.xsd.commonbasiccomponents_21.AmountType.class,
    AnnualAverageAmountType.class,
    AverageAmountType.class,
    AverageSubsequentContractAmountType.class,
    BalanceAmountType.class,
    BaseAmountType.class,
    CallBaseAmountType.class,
    CallExtensionAmountType.class,
    ChargeTotalAmountType.class,
    CorporateStockAmountType.class,
    CorrectionAmountType.class,
    CorrectionUnitAmountType.class,
    CreditLineAmountType.class,
    DebitLineAmountType.class,
    DeclaredCarriageValueAmountType.class,
    DeclaredCustomsValueAmountType.class,
    DeclaredForCarriageValueAmountType.class,
    DeclaredStatisticsValueAmountType.class,
    DocumentationFeeAmountType.class,
    EstimatedAmountType.class,
    EstimatedOverallContractAmountType.class,
    FaceValueAmountType.class,
    FeeAmountType.class,
    FreeOnBoardValueAmountType.class,
    HigherTenderAmountType.class,
    InsurancePremiumAmountType.class,
    InsuranceValueAmountType.class,
    InventoryValueAmountType.class,
    LiabilityAmountType.class,
    LineExtensionAmountType.class,
    LowerTenderAmountType.class,
    MarketValueAmountType.class,
    MaximumAdvertisementAmountType.class,
    MaximumAmountType.class,
    MaximumPaidAmountType.class,
    MinimumAmountType.class,
    PaidAmountType.class,
    PartyCapacityAmountType.class,
    PayableAlternativeAmountType.class,
    PayableAmountType.class,
    PayableRoundingAmountType.class,
    PenaltyAmountType.class,
    PerUnitAmountType.class,
    PrepaidAmountType.class,
    PriceAmountType.class,
    RequiredFeeAmountType.class,
    RoundingAmountType.class,
    SettlementDiscountAmountType.class,
    TaxAmountType.class,
    TaxEnergyAmountType.class,
    TaxEnergyBalanceAmountType.class,
    TaxEnergyOnAccountAmountType.class,
    TaxExclusiveAmountType.class,
    TaxInclusiveAmountType.class,
    TaxableAmountType.class,
    ThresholdAmountType.class,
    TotalAmountType.class,
    TotalBalanceAmountType.class,
    TotalCreditAmountType.class,
    TotalDebitAmountType.class,
    TotalInvoiceAmountType.class,
    TotalPaymentAmountType.class,
    TotalTaskAmountType.class,
    TotalTaxAmountType.class,
    TransactionCurrencyTaxAmountType.class,
    ValueAmountType.class
})
@CodingStyleguideUnaware
public class AmountType
    extends com.helger.xsds.ccts.cct.schemamodule.AmountType
    implements Serializable
{


    /**
     * Default constructor&lt;br&gt;
     * Note: automatically created by ph-jaxb22-plugin -Xph-value-extender
     * 
     */
    public AmountType() {
    }

    /**
     * Constructor for value of type BigDecimal&lt;br&gt;
     * Note: automatically created by ph-jaxb22-plugin -Xph-value-extender
     * 
     * @param valueParam
     *     The value to be set. May be &lt;code&gt;null&lt;/code&gt;.
     */
    public AmountType(
        @Nullable
        final BigDecimal valueParam) {
        setValue(valueParam);
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-equalshashcode
     * 
     */
    @Override
    public boolean equals(final Object o) {
        return super.equals(o);
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-equalshashcode
     * 
     */
    @Override
    public int hashCode() {
        return super.hashCode();
    }

    /**
     * This method clones all values from &lt;code&gt;this&lt;/code&gt; to the passed object. All data in the parameter object is overwritten!Created by ph-jaxb22-plugin -Xph-cloneable2
     * 
     * @param ret
     *     The target object to clone to. May not be &lt;code&gt;null&lt;/code&gt;.
     */
    public void cloneTo(
        @Nonnull
        AmountType ret) {
        super.cloneTo(ret);
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-cloneable2
     * 
     * @return
     *     The cloned object. Never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    @ReturnsMutableCopy
    @Override
    public AmountType clone() {
        AmountType ret = new AmountType();
        cloneTo(ret);
        return ret;
    }

}
